pub struct CachedRecipient { /* private fields */ }Expand description
Zero-KDF recipient for session writes.
Wraps the FileKey using the cached wrapping key and salt, avoiding any Argon2id computation.
Implementations
Sourceimpl CachedRecipient
impl CachedRecipient
Sourcepub fn new(material: &CachedMaterial) -> Self
pub fn new(material: &CachedMaterial) -> Self
Create a new cached recipient from previously captured key material.